summaryrefslogtreecommitdiffstats
path: root/src/modules
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules')
-rw-r--r--src/modules/addon/managementdialog.cpp2
-rw-r--r--src/modules/aliaseditor/aliaseditor.cpp8
-rw-r--r--src/modules/aliaseditor/aliaseditor.h2
-rw-r--r--src/modules/chan/libkvichan.cpp14
-rw-r--r--src/modules/list/listwindow.cpp2
-rw-r--r--src/modules/mask/libkvimask.cpp28
-rw-r--r--src/modules/my/libkvimy.cpp2
-rw-r--r--src/modules/objects/class_button.cpp2
-rw-r--r--src/modules/objects/class_buttongroup.cpp4
-rw-r--r--src/modules/objects/class_checkbox.cpp2
-rw-r--r--src/modules/objects/class_combobox.cpp2
-rw-r--r--src/modules/objects/class_dialog.cpp2
-rw-r--r--src/modules/objects/class_groupbox.cpp24
-rw-r--r--src/modules/objects/class_hbox.cpp4
-rw-r--r--src/modules/objects/class_label.cpp2
-rw-r--r--src/modules/objects/class_layout.cpp2
-rw-r--r--src/modules/objects/class_lcd.cpp2
-rw-r--r--src/modules/objects/class_lineedit.cpp2
-rw-r--r--src/modules/objects/class_listbox.cpp2
-rw-r--r--src/modules/objects/class_listview.cpp2
-rw-r--r--src/modules/objects/class_listviewitem.cpp12
-rw-r--r--src/modules/objects/class_mainwindow.cpp2
-rw-r--r--src/modules/objects/class_menubar.cpp2
-rw-r--r--src/modules/objects/class_multilineedit.cpp2
-rw-r--r--src/modules/objects/class_popupmenu.cpp2
-rw-r--r--src/modules/objects/class_process.cpp12
-rw-r--r--src/modules/objects/class_progressbar.cpp4
-rw-r--r--src/modules/objects/class_radiobutton.cpp2
-rw-r--r--src/modules/objects/class_slider.cpp2
-rw-r--r--src/modules/objects/class_spinbox.cpp2
-rw-r--r--src/modules/objects/class_tabwidget.cpp18
-rw-r--r--src/modules/objects/class_tbrowser.cpp2
-rw-r--r--src/modules/objects/class_toolbar.cpp6
-rw-r--r--src/modules/objects/class_toolbutton.cpp2
-rw-r--r--src/modules/objects/class_vbox.cpp4
-rw-r--r--src/modules/objects/class_widget.cpp10
-rw-r--r--src/modules/objects/class_wizard.cpp2
-rw-r--r--src/modules/objects/class_workspace.cpp2
-rw-r--r--src/modules/options/dialog.cpp2
-rw-r--r--src/modules/popupeditor/popupeditor.cpp8
-rw-r--r--src/modules/regchan/libkviregchan.cpp4
-rw-r--r--src/modules/reguser/dialog.cpp4
-rw-r--r--src/modules/reguser/edituser.cpp8
-rw-r--r--src/modules/reguser/edituser.h2
-rw-r--r--src/modules/reguser/libkvireguser.cpp42
-rw-r--r--src/modules/reguser/wizard.cpp14
-rw-r--r--src/modules/reguser/wizard.h2
-rw-r--r--src/modules/system/libkvisystem.cpp2
-rw-r--r--src/modules/tip/libkvitip_it.kvc2
-rw-r--r--src/modules/toolbareditor/toolbareditor.cpp2
50 files changed, 145 insertions, 145 deletions
diff --git a/src/modules/addon/managementdialog.cpp b/src/modules/addon/managementdialog.cpp
index adbbae7..5a58779 100644
--- a/src/modules/addon/managementdialog.cpp
+++ b/src/modules/addon/managementdialog.cpp
@@ -370,7 +370,7 @@ void KviScriptManagementDialog::installScript()
void KviScriptManagementDialog::showEvent(TQShowEvent * e)
{
-// TQRect r = tqparentWidget() ? tqparentWidget()->rect() : TQApplication::desktop()->rect();
+// TQRect r = parentWidget() ? parentWidget()->rect() : TQApplication::desktop()->rect();
// int x = (r.width() - width()) / 2;
// int y = (r.height() - height()) / 2;
// move(x,y);
diff --git a/src/modules/aliaseditor/aliaseditor.cpp b/src/modules/aliaseditor/aliaseditor.cpp
index 74d3752..a8c8c6f 100644
--- a/src/modules/aliaseditor/aliaseditor.cpp
+++ b/src/modules/aliaseditor/aliaseditor.cpp
@@ -310,7 +310,7 @@ TQString KviAliasEditor::buildFullItemName(KviAliasEditorListViewItem * it)
{
if(!it) return TQString();
TQString szName = it->name();
- KviAliasNamespaceListViewItem * nit = it->tqparentNamespaceItem();
+ KviAliasNamespaceListViewItem * nit = it->parentNamespaceItem();
while(nit)
{
TQString tmp = nit->name();
@@ -319,7 +319,7 @@ TQString KviAliasEditor::buildFullItemName(KviAliasEditorListViewItem * it)
szName.prepend("::");
szName.prepend(tmp);
}
- nit = nit->tqparentNamespaceItem();
+ nit = nit->parentNamespaceItem();
}
return szName;
}
@@ -1024,7 +1024,7 @@ void KviAliasEditor::newAlias()
{
if(!itemExists(m_pLastClickedItem,m_pListView->firstChild()))return; // dead ?
if(m_pLastClickedItem->isAlias())
- m_pLastClickedItem = m_pLastClickedItem->tqparentNamespaceItem();
+ m_pLastClickedItem = m_pLastClickedItem->parentNamespaceItem();
}
TQString szNewName = askForAliasName(__tr2qs("Add Alias"),__tr2qs("Please enter the name for the new alias"),"myfunction");
@@ -1048,7 +1048,7 @@ void KviAliasEditor::newNamespace()
{
if(!itemExists(m_pLastClickedItem,m_pListView->firstChild()))return; // dead ?
if(m_pLastClickedItem->isAlias())
- m_pLastClickedItem = m_pLastClickedItem->tqparentNamespaceItem();
+ m_pLastClickedItem = m_pLastClickedItem->parentNamespaceItem();
}
diff --git a/src/modules/aliaseditor/aliaseditor.h b/src/modules/aliaseditor/aliaseditor.h
index 570fe94..927963b 100644
--- a/src/modules/aliaseditor/aliaseditor.h
+++ b/src/modules/aliaseditor/aliaseditor.h
@@ -60,7 +60,7 @@ public:
bool isAlias(){ return m_eType == Alias; };
bool isNamespace(){ return m_eType == Namespace; };
void setParentNamespaceItem(KviAliasNamespaceListViewItem* it){ m_pParentNamespaceItem=it; };
- KviAliasNamespaceListViewItem * tqparentNamespaceItem(){ return m_pParentNamespaceItem; };
+ KviAliasNamespaceListViewItem * parentNamespaceItem(){ return m_pParentNamespaceItem; };
virtual TQString key(int column,bool bAsc) const;
};
diff --git a/src/modules/chan/libkvichan.cpp b/src/modules/chan/libkvichan.cpp
index a2ff3bb..b7600f8 100644
--- a/src/modules/chan/libkvichan.cpp
+++ b/src/modules/chan/libkvichan.cpp
@@ -1040,7 +1040,7 @@ static bool chan_kvs_fnc_limit(KviKvsModuleFunctionCall * c)
"ovhn" are mode flags: the users are added to the array only if they are channel administrators ('a'), operators ('o'),
voiced users ('v'), half-operators ('h'), user-operators ('u') or unflagged ('n') users. (Unflagged means not operators, not
voiced and not half-operators). If none of the "ovhun" flags are used, KVIrc behaves like all five were passed.[br]
- The flag 'm' causes the entire user tqmasks to be added to the
+ The flag 'm' causes the entire user masks to be added to the
array entries, as known by KVIrc at the moment of this function call.[br]
The flag 'i' causes KVIrc to invert the match and add only the users that do NOT match [tqmask].[br]
Please note that on really large channels this function may be time consuming (especially if [tqmask] is used):
@@ -1182,11 +1182,11 @@ next_item:
@title:
$chan.banlist
@short:
- Returns an array of channel ban tqmasks
+ Returns an array of channel ban masks
@syntax:
$chan.banlist([window_id])
@description:
- Returns an array of ban tqmasks set ont the channel identified by [window_id].[br]
+ Returns an array of ban masks set ont the channel identified by [window_id].[br]
If [window_id] is empty, the current window is used.[br]
If the window designated by [window_id] is not a channel a warning is printed and an empty array is returned.[br]
*/
@@ -1225,11 +1225,11 @@ static bool chan_kvs_fnc_banlist(KviKvsModuleFunctionCall * c)
@title:
$chan.banexceptionlist
@short:
- Returns an array of channel ban exception tqmasks
+ Returns an array of channel ban exception masks
@syntax:
<array> $chan.banexceptionlist([window_id])
@description:
- Returns an array of ban exception tqmasks set ont the channel identified by [window_id].[br]
+ Returns an array of ban exception masks set ont the channel identified by [window_id].[br]
If [window_id] is empty, the current window is used.[br]
If the window designated by [window_id] is not a channel a warning is printed and an empty array is returned.[br]
*/
@@ -1268,11 +1268,11 @@ static bool chan_kvs_fnc_banexceptionlist(KviKvsModuleFunctionCall * c)
@title:
$chan.invitelist
@short:
- Returns an array of channel invite tqmasks
+ Returns an array of channel invite masks
@syntax:
<array> $chan.banexceptionlist([window_id])
@description:
- Returns an array of invite tqmasks set ont the channel identified by [window_id].[br]
+ Returns an array of invite masks set ont the channel identified by [window_id].[br]
If [window_id] is empty, the current window is used.[br]
If the window designated by [window_id] is not a channel a warning is printed and an empty array is returned.[br]
*/
diff --git a/src/modules/list/listwindow.cpp b/src/modules/list/listwindow.cpp
index 57fb170..c9d56e3 100644
--- a/src/modules/list/listwindow.cpp
+++ b/src/modules/list/listwindow.cpp
@@ -210,7 +210,7 @@ KviListWindow::KviListWindow(KviFrame * lpFrm,KviConsole * lpConsole)
box->setStretchFactor(m_pParamsEdit,1);
TQToolTip::add(m_pParamsEdit,__tr2qs("<center><b>/LIST command parameters:</b><br>Many servers accept special parameters that " \
"allow you to filter the returned entries.<br>" \
- "Commonly, tqmasked channel names (*kvirc*) are accepted as parameters, as well as strings " \
+ "Commonly, masked channel names (*kvirc*) are accepted as parameters, as well as strings " \
"like <b>c&lt;n</b> or <b>c&gt;n</b> where <b>n</b> is the minimum or maximum of users on the channel.</center>"));
m_pInfoLabel = new KviThemedLabel(m_pTopSplitter,"info_label");
diff --git a/src/modules/mask/libkvimask.cpp b/src/modules/mask/libkvimask.cpp
index 0e810c3..0c75fc5 100644
--- a/src/modules/mask/libkvimask.cpp
+++ b/src/modules/mask/libkvimask.cpp
@@ -47,7 +47,7 @@
[/example]
*/
-static bool tqmask_kvs_fnc_match(KviKvsModuleFunctionCall * c)
+static bool mask_kvs_fnc_match(KviKvsModuleFunctionCall * c)
{
TQString wildtqmask,fixedtqmask;
@@ -75,7 +75,7 @@ static bool tqmask_kvs_fnc_match(KviKvsModuleFunctionCall * c)
Returns the nickname part of an IRC tqmask.
*/
-static bool tqmask_kvs_fnc_nick(KviKvsModuleFunctionCall * c)
+static bool mask_kvs_fnc_nick(KviKvsModuleFunctionCall * c)
{
TQString tqmask;
@@ -101,7 +101,7 @@ static bool tqmask_kvs_fnc_nick(KviKvsModuleFunctionCall * c)
Returns the username part of an IRC tqmask.
*/
-static bool tqmask_kvs_fnc_user(KviKvsModuleFunctionCall * c)
+static bool mask_kvs_fnc_user(KviKvsModuleFunctionCall * c)
{
TQString tqmask;
@@ -128,7 +128,7 @@ static bool tqmask_kvs_fnc_user(KviKvsModuleFunctionCall * c)
Returns the hostname part of an IRC tqmask.
*/
-static bool tqmask_kvs_fnc_host(KviKvsModuleFunctionCall * c)
+static bool mask_kvs_fnc_host(KviKvsModuleFunctionCall * c)
{
TQString tqmask;
KVSM_PARAMETERS_BEGIN(c)
@@ -155,7 +155,7 @@ static bool tqmask_kvs_fnc_host(KviKvsModuleFunctionCall * c)
*/
-static bool tqmask_kvs_fnc_hasnumerichost(KviKvsModuleFunctionCall * c)
+static bool mask_kvs_fnc_hasnumerichost(KviKvsModuleFunctionCall * c)
{
TQString tqmask;
KVSM_PARAMETERS_BEGIN(c)
@@ -173,18 +173,18 @@ static bool tqmask_kvs_fnc_hasnumerichost(KviKvsModuleFunctionCall * c)
-static bool tqmask_module_init(KviModule * m)
+static bool mask_module_init(KviModule * m)
{
- KVSM_REGISTER_FUNCTION(m,"match",tqmask_kvs_fnc_match);
- KVSM_REGISTER_FUNCTION(m,"nick",tqmask_kvs_fnc_nick);
- KVSM_REGISTER_FUNCTION(m,"user",tqmask_kvs_fnc_user);
- KVSM_REGISTER_FUNCTION(m,"host",tqmask_kvs_fnc_host);
- KVSM_REGISTER_FUNCTION(m,"hasnumerichost",tqmask_kvs_fnc_hasnumerichost);
+ KVSM_REGISTER_FUNCTION(m,"match",mask_kvs_fnc_match);
+ KVSM_REGISTER_FUNCTION(m,"nick",mask_kvs_fnc_nick);
+ KVSM_REGISTER_FUNCTION(m,"user",mask_kvs_fnc_user);
+ KVSM_REGISTER_FUNCTION(m,"host",mask_kvs_fnc_host);
+ KVSM_REGISTER_FUNCTION(m,"hasnumerichost",mask_kvs_fnc_hasnumerichost);
return true;
}
-static bool tqmask_module_cleanup(KviModule *m)
+static bool mask_module_cleanup(KviModule *m)
{
return true;
}
@@ -194,8 +194,8 @@ KVIRC_MODULE(
"1.0.0", // module version
"Copyright (C) 2002 Szymon Stefanek (pragma at kvirc dot net)",
"Mask manipulation functions",
- tqmask_module_init,
+ mask_module_init,
0,
0,
- tqmask_module_cleanup
+ mask_module_cleanup
)
diff --git a/src/modules/my/libkvimy.cpp b/src/modules/my/libkvimy.cpp
index 07a9376..d98d44a 100644
--- a/src/modules/my/libkvimy.cpp
+++ b/src/modules/my/libkvimy.cpp
@@ -247,7 +247,7 @@ static bool my_kvs_fnc_host(KviKvsModuleFunctionCall * c)
@description:
Returns the ip address of the current irc context as known by the IRC server.[br]
The ip address is resolved as soon as the hostname is received from the server.
- If the hostname is tqmasked or there is an error in the DNS lookup then
+ If the hostname is masked or there is an error in the DNS lookup then
you may get the real local host ip address as determined at connection startup.[br]
If the irc context is not connected then an empty string is returned.[br]
If <irc_context_id> is specified this function returns acts as it was called
diff --git a/src/modules/objects/class_button.cpp b/src/modules/objects/class_button.cpp
index c3710cc..a23dcda 100644
--- a/src/modules/objects/class_button.cpp
+++ b/src/modules/objects/class_button.cpp
@@ -57,7 +57,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_button)
bool KviKvsObject_button::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQPushButton(tqparentScriptWidget(),name())),true);
+ setObject(TQT_TQOBJECT(new TQPushButton(parentScriptWidget(),name())),true);
connect(widget(),TQT_SIGNAL(clicked()),this,TQT_SLOT(slotClicked()));
return true;
}
diff --git a/src/modules/objects/class_buttongroup.cpp b/src/modules/objects/class_buttongroup.cpp
index 611341a..d0f2554 100644
--- a/src/modules/objects/class_buttongroup.cpp
+++ b/src/modules/objects/class_buttongroup.cpp
@@ -73,11 +73,11 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_buttongroup)
bool KviKvsObject_buttongroup::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
#ifdef COMPILE_USE_QT4
- TQButtonGroup *group=new TQButtonGroup(tqparentScriptWidget());
+ TQButtonGroup *group=new TQButtonGroup(parentScriptWidget());
group->setObjectName(name());
setObject(group,true);
#else
- setObject(TQT_TQOBJECT(new TQButtonGroup(name(),tqparentScriptWidget())), true);
+ setObject(TQT_TQOBJECT(new TQButtonGroup(name(),parentScriptWidget())), true);
#endif
diff --git a/src/modules/objects/class_checkbox.cpp b/src/modules/objects/class_checkbox.cpp
index 27a0fc1..758e414 100644
--- a/src/modules/objects/class_checkbox.cpp
+++ b/src/modules/objects/class_checkbox.cpp
@@ -79,7 +79,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_checkbox)
bool KviKvsObject_checkbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- KviStyledCheckBox * cb = new KviStyledCheckBox(tqparentScriptWidget(), name());
+ KviStyledCheckBox * cb = new KviStyledCheckBox(parentScriptWidget(), name());
setObject(TQT_TQOBJECT(cb), true);
connect(cb,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(toggled(bool)));
connect(widget(),TQT_SIGNAL(clicked()),this,TQT_SLOT(slotClicked()));
diff --git a/src/modules/objects/class_combobox.cpp b/src/modules/objects/class_combobox.cpp
index 38f4472..88a1b42 100644
--- a/src/modules/objects/class_combobox.cpp
+++ b/src/modules/objects/class_combobox.cpp
@@ -132,7 +132,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_combobox)
bool KviKvsObject_combobox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQComboBox(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQComboBox(parentScriptWidget(), name())), true);
connect (((TQComboBox *)widget()),TQT_SIGNAL(activated( int )),this,TQT_SLOT(slotActivated( int )));
return true;
}
diff --git a/src/modules/objects/class_dialog.cpp b/src/modules/objects/class_dialog.cpp
index b5515a7..490aabb 100644
--- a/src/modules/objects/class_dialog.cpp
+++ b/src/modules/objects/class_dialog.cpp
@@ -70,7 +70,7 @@ bool KviKvsObject_dialog::init(KviKvsRunTimeContext * pContext,KviKvsVariantList
{
TQWidget * w = TQT_TQWIDGET(g_pApp->activeModalWidget());
if(!w)w = g_pFrame;
- TQDialog * d = new TQDialog(tqparentScriptWidget() ? tqparentScriptWidget() : w,name());
+ TQDialog * d = new TQDialog(parentScriptWidget() ? parentScriptWidget() : w,name());
//d->setModal(true);
setObject(TQT_TQOBJECT(d));
return true;
diff --git a/src/modules/objects/class_groupbox.cpp b/src/modules/objects/class_groupbox.cpp
index 023d1e2..f741f70 100644
--- a/src/modules/objects/class_groupbox.cpp
+++ b/src/modules/objects/class_groupbox.cpp
@@ -119,23 +119,23 @@ const int align_cod[] = {
%inputpass=$new(lineedit,%gb)[br]
%inputpass->$setechomode("password")[br]
[br]
- #now lets' tqlayouting the groupbox's element's.[br]
- %tqlayoutgb=$new(tqlayout,%gb)[br]
- %tqlayoutgb->$setmargin(20)[br]
- %tqlayoutgb->$addwidget(%labeluser,0,0)[br]
- %tqlayoutgb->$addwidget(%labelpass,1,0)[br]
- %tqlayoutgb->$addwidget(%inputuser,0,1)[br]
- %tqlayoutgb->$addwidget(%inputpass,1,1)[br]
+ #now lets' layouting the groupbox's element's.[br]
+ %layoutgb=$new(tqlayout,%gb)[br]
+ %layoutgb->$setmargin(20)[br]
+ %layoutgb->$addwidget(%labeluser,0,0)[br]
+ %layoutgb->$addwidget(%labelpass,1,0)[br]
+ %layoutgb->$addwidget(%inputuser,0,1)[br]
+ %layoutgb->$addwidget(%inputpass,1,1)[br]
[br]
# now we create a fake widget and managing the two buttons tqlayout.[br]
%fakewidget=$new(widget,%widget)[br]
- %tqlayoutbtn=$new(tqlayout,%fakewidget)[br]
+ %layoutbtn=$new(tqlayout,%fakewidget)[br]
%btnok=$new(button,%fakewidget)[br]
%btnok->$settext("OK")[br]
%btncancel=$new(button,%fakewidget)[br]
%btncancel->$settext("Cancel")[br]
- %tqlayoutbtn->$addwidget(%btnok,0,0)[br]
- %tqlayoutbtn->$addwidget(%btncancel,0,1)[br]
+ %layoutbtn->$addwidget(%btnok,0,0)[br]
+ %layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
#And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
#and fakewiget (with its buttons tqchildren).
@@ -185,11 +185,11 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_groupbox)
bool KviKvsObject_groupbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
#ifdef COMPILE_USE_QT4
- KviTalGroupBox *groupbox=new KviTalGroupBox(name(),tqparentScriptWidget());
+ KviTalGroupBox *groupbox=new KviTalGroupBox(name(),parentScriptWidget());
groupbox->setObjectName(name());
setObject(groupbox,true);
#else
- setObject(TQT_TQOBJECT(new KviTalGroupBox(name(),tqparentScriptWidget())), true);
+ setObject(TQT_TQOBJECT(new KviTalGroupBox(name(),parentScriptWidget())), true);
#endif
return true;
}
diff --git a/src/modules/objects/class_hbox.cpp b/src/modules/objects/class_hbox.cpp
index cf85564..58c518c 100644
--- a/src/modules/objects/class_hbox.cpp
+++ b/src/modules/objects/class_hbox.cpp
@@ -68,7 +68,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_hbox)
bool KviKvsObject_hbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new KviTalHBox(tqparentScriptWidget())), true);
+ setObject(TQT_TQOBJECT(new KviTalHBox(parentScriptWidget())), true);
return true;
}
bool KviKvsObject_hbox::functionsetMargin(KviKvsObjectFunctionCall *c)
@@ -116,7 +116,7 @@ bool KviKvsObject_hbox::functionsetStretchFactor(KviKvsObjectFunctionCall *c)
c->warning(__tr2qs("Can't add a non-widget object"));
return true;
}
- if(((KviKvsObject_widget *)pObject)->widget()->tqparentWidget() != widget())
+ if(((KviKvsObject_widget *)pObject)->widget()->parentWidget() != widget())
{
c->warning(__tr2qs("The widget must be a child of this hbox"));
return true;
diff --git a/src/modules/objects/class_label.cpp b/src/modules/objects/class_label.cpp
index fcde9a1..20184b9 100644
--- a/src/modules/objects/class_label.cpp
+++ b/src/modules/objects/class_label.cpp
@@ -235,7 +235,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_label)
bool KviKvsObject_label::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQLabel(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQLabel(parentScriptWidget(), name())), true);
return true;
}
diff --git a/src/modules/objects/class_layout.cpp b/src/modules/objects/class_layout.cpp
index cac963b..3cc6a0e 100644
--- a/src/modules/objects/class_layout.cpp
+++ b/src/modules/objects/class_layout.cpp
@@ -112,7 +112,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_layout)
bool KviKvsObject_layout::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- TQWidget * w = tqparentScriptWidget();
+ TQWidget * w = parentScriptWidget();
if(!w)
{
diff --git a/src/modules/objects/class_lcd.cpp b/src/modules/objects/class_lcd.cpp
index 539457b..3b40b64 100644
--- a/src/modules/objects/class_lcd.cpp
+++ b/src/modules/objects/class_lcd.cpp
@@ -89,7 +89,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_lcd)
bool KviKvsObject_lcd::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQLCDNumber(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQLCDNumber(parentScriptWidget(), name())), true);
return true;
}
diff --git a/src/modules/objects/class_lineedit.cpp b/src/modules/objects/class_lineedit.cpp
index e429adf..8844d1b 100644
--- a/src/modules/objects/class_lineedit.cpp
+++ b/src/modules/objects/class_lineedit.cpp
@@ -218,7 +218,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_lineedit)
bool KviKvsObject_lineedit::init(KviKvsRunTimeContext * pContext,KviKvsVariantList * pParams)
{
- setObject(TQT_TQOBJECT(new TQLineEdit(tqparentScriptWidget(),getName())),true);
+ setObject(TQT_TQOBJECT(new TQLineEdit(parentScriptWidget(),getName())),true);
connect(widget(),TQT_SIGNAL(returnPressed()),this,TQT_SLOT(slotreturnPressed()));
connect(widget(),TQT_SIGNAL(lostFocus()),this,TQT_SLOT(slotlostFocus()));
connect(widget(),TQT_SIGNAL(textChanged(const TQString & )),this,TQT_SLOT(slottextChanged(const TQString & )));
diff --git a/src/modules/objects/class_listbox.cpp b/src/modules/objects/class_listbox.cpp
index db3920f..241c385 100644
--- a/src/modules/objects/class_listbox.cpp
+++ b/src/modules/objects/class_listbox.cpp
@@ -150,7 +150,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_listbox)
bool KviKvsObject_listbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- KviTalListBox * b = new KviTalListBox(tqparentScriptWidget());
+ KviTalListBox * b = new KviTalListBox(parentScriptWidget());
b->setSelectionMode(KviTalListBox::Single);
connect(b,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(selectionChanged()));
connect(b,TQT_SIGNAL(currentChanged(KviTalListBoxItem *)),this,TQT_SLOT(currentItemChanged(KviTalListBoxItem *)));
diff --git a/src/modules/objects/class_listview.cpp b/src/modules/objects/class_listview.cpp
index 036e758..8dd485a 100644
--- a/src/modules/objects/class_listview.cpp
+++ b/src/modules/objects/class_listview.cpp
@@ -217,7 +217,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_listview)
bool KviKvsObject_listview::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new KviKvsMdmListView(tqparentScriptWidget(),name(),this)),true);
+ setObject(TQT_TQOBJECT(new KviKvsMdmListView(parentScriptWidget(),name(),this)),true);
connect(widget(),TQT_SIGNAL(clicked(KviTalListViewItem *)),this,TQT_SLOT(slotClicked(KviTalListViewItem *)));
connect(widget(),TQT_SIGNAL(selectionChanged(KviTalListViewItem *)),this,TQT_SLOT(slotSelectionChanged(KviTalListViewItem *)));
connect(widget(),TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(slotMultipleSelectionChanged()));
diff --git a/src/modules/objects/class_listviewitem.cpp b/src/modules/objects/class_listviewitem.cpp
index 0834796..f382628 100644
--- a/src/modules/objects/class_listviewitem.cpp
+++ b/src/modules/objects/class_listviewitem.cpp
@@ -137,17 +137,17 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_listviewitem)
bool KviKvsObject_listviewitem::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- if (!tqparentObject())
+ if (!parentObject())
{
- pContext->error(__tr2qs("The listviewitem cannot be tqparentless"));
+ pContext->error(__tr2qs("The listviewitem cannot be parentless"));
return false;
}
- if(tqparentObject()->inherits("KviKvsObject_listviewitem"))
+ if(parentObject()->inherits("KviKvsObject_listviewitem"))
{
- m_pListViewItem = new KviKvsMdmStandardListViewItem(this,((KviKvsObject_listviewitem *)tqparentObject())->m_pListViewItem);
+ m_pListViewItem = new KviKvsMdmStandardListViewItem(this,((KviKvsObject_listviewitem *)parentObject())->m_pListViewItem);
} else {
- if(tqparentObject()->inherits("KviKvsObject_listview"))
- m_pListViewItem = new KviKvsMdmStandardListViewItem(this,((KviTalListView *)tqparentScriptWidget()));
+ if(parentObject()->inherits("KviKvsObject_listview"))
+ m_pListViewItem = new KviKvsMdmStandardListViewItem(this,((KviTalListView *)parentScriptWidget()));
else {
pContext->error(__tr2qs("The tqparent of the listviewitem must be either another listviewitem or a listview"));
return false;
diff --git a/src/modules/objects/class_mainwindow.cpp b/src/modules/objects/class_mainwindow.cpp
index 8b04053..47c8fc6 100644
--- a/src/modules/objects/class_mainwindow.cpp
+++ b/src/modules/objects/class_mainwindow.cpp
@@ -68,7 +68,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_mainwindow)
bool KviKvsObject_mainwindow::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new KviTalMainWindow(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new KviTalMainWindow(parentScriptWidget(), name())), true);
return true;
}
diff --git a/src/modules/objects/class_menubar.cpp b/src/modules/objects/class_menubar.cpp
index 860ffaf..9394597 100644
--- a/src/modules/objects/class_menubar.cpp
+++ b/src/modules/objects/class_menubar.cpp
@@ -61,7 +61,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_menubar)
bool KviKvsObject_menubar::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQMenuBar(tqparentScriptWidget(), name())));
+ setObject(TQT_TQOBJECT(new TQMenuBar(parentScriptWidget(), name())));
return true;
}
diff --git a/src/modules/objects/class_multilineedit.cpp b/src/modules/objects/class_multilineedit.cpp
index fa9181e..a4beed4 100644
--- a/src/modules/objects/class_multilineedit.cpp
+++ b/src/modules/objects/class_multilineedit.cpp
@@ -353,7 +353,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_mledit)
bool KviKvsObject_mledit::init(KviKvsRunTimeContext * pContext,KviKvsVariantList * pParams)
{
- setObject(TQT_TQOBJECT(new KviTalMultiLineEdit(tqparentScriptWidget(),getName())),true);
+ setObject(TQT_TQOBJECT(new KviTalMultiLineEdit(parentScriptWidget(),getName())),true);
return true;
}
diff --git a/src/modules/objects/class_popupmenu.cpp b/src/modules/objects/class_popupmenu.cpp
index 17bf5c0..394c39a 100644
--- a/src/modules/objects/class_popupmenu.cpp
+++ b/src/modules/objects/class_popupmenu.cpp
@@ -184,7 +184,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_popupmenu)
bool KviKvsObject_popupmenu::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new KviTalPopupMenu(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new KviTalPopupMenu(parentScriptWidget(), name())), true);
connect(widget(),TQT_SIGNAL(activated(int)),this,TQT_SLOT(slotactivated(int)));
connect(widget(),TQT_SIGNAL(highlighted(int)),this,TQT_SLOT(slothighlighted(int)));
return true;
diff --git a/src/modules/objects/class_process.cpp b/src/modules/objects/class_process.cpp
index 16ed7a4..9ec6cc5 100644
--- a/src/modules/objects/class_process.cpp
+++ b/src/modules/objects/class_process.cpp
@@ -82,7 +82,7 @@
%tt=$new(test)[br]
%A=$new(widget)[br]
%A->$setGeometry(100,100,400,300)[br]
- %tqlayoutA=$new(tqlayout,%A)[br]
+ %layoutA=$new(tqlayout,%A)[br]
%Ainput=$new(lineedit,%A)[br]
#%Aoutput=$new(textedit,%A)// coming soon in the new texteditor class[br]
%Aoutput=$new(label,%A)[br]
@@ -92,11 +92,11 @@
%bkill->$settext("&Kill ")[br]
%bterminate=$new(button,%A)[br]
%bterminate->$settext("&Ask to Terminate ")[br]
- %tqlayoutA->$addwidget(%Ainput,0,0)[br]
- %tqlayoutA->$addwidget(%Aoutput,1,0)[br]
- %tqlayoutA->$addwidget(%bclosekill,3,0)[br]
- %tqlayoutA->$addwidget(%bkill,4,0,)[br]
- %tqlayoutA->$addwidget(%bterminate,5,0)[br]
+ %layoutA->$addwidget(%Ainput,0,0)[br]
+ %layoutA->$addwidget(%Aoutput,1,0)[br]
+ %layoutA->$addwidget(%bclosekill,3,0)[br]
+ %layoutA->$addwidget(%bkill,4,0,)[br]
+ %layoutA->$addwidget(%bterminate,5,0)[br]
%Process=$new(process)[br]
%Process->$addArg("cmd.exe")[br]
diff --git a/src/modules/objects/class_progressbar.cpp b/src/modules/objects/class_progressbar.cpp
index b75c144..bfaa1ec 100644
--- a/src/modules/objects/class_progressbar.cpp
+++ b/src/modules/objects/class_progressbar.cpp
@@ -96,11 +96,11 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_progressbar)
bool KviKvsObject_progressbar::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
#ifdef COMPILE_USE_QT4
- Q3ProgressBar *pbar=new Q3ProgressBar(tqparentScriptWidget());
+ Q3ProgressBar *pbar=new Q3ProgressBar(parentScriptWidget());
pbar->setObjectName(name());
setObject(pbar,true);
#else
- setObject(TQT_TQOBJECT(new TQProgressBar(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQProgressBar(parentScriptWidget(), name())), true);
#endif
return true;
}
diff --git a/src/modules/objects/class_radiobutton.cpp b/src/modules/objects/class_radiobutton.cpp
index 75a20f5..204909a 100644
--- a/src/modules/objects/class_radiobutton.cpp
+++ b/src/modules/objects/class_radiobutton.cpp
@@ -82,7 +82,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_radiobutton)
bool KviKvsObject_radiobutton::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQRadioButton(tqparentScriptWidget(),name())),true);
+ setObject(TQT_TQOBJECT(new TQRadioButton(parentScriptWidget(),name())),true);
connect(widget(),TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(toggled(bool)));
return true;
}
diff --git a/src/modules/objects/class_slider.cpp b/src/modules/objects/class_slider.cpp
index 2357da5..a8e3d93 100644
--- a/src/modules/objects/class_slider.cpp
+++ b/src/modules/objects/class_slider.cpp
@@ -130,7 +130,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_slider)
bool KviKvsObject_slider::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQSlider(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQSlider(parentScriptWidget(), name())), true);
connect(widget(),TQT_SIGNAL(valueChanged(int)),this,TQT_SLOT(valueChanged(int)));
return true;
}
diff --git a/src/modules/objects/class_spinbox.cpp b/src/modules/objects/class_spinbox.cpp
index 62f7df5..c7ad092 100644
--- a/src/modules/objects/class_spinbox.cpp
+++ b/src/modules/objects/class_spinbox.cpp
@@ -132,7 +132,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_spinbox)
bool KviKvsObject_spinbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQSpinBox(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQSpinBox(parentScriptWidget(), name())), true);
connect(widget(),TQT_SIGNAL(valueChanged(int)),this,TQT_SLOT(valueChanged(int)));
return true;
}
diff --git a/src/modules/objects/class_tabwidget.cpp b/src/modules/objects/class_tabwidget.cpp
index 57e30a1..d30a6b6 100644
--- a/src/modules/objects/class_tabwidget.cpp
+++ b/src/modules/objects/class_tabwidget.cpp
@@ -94,7 +94,7 @@
%secondtab=$new(widget,%Tabwidget)
# Now we'll create the item to put in to tab's pages.
- %tqlayoutfirsttab=$new(tqlayout,%firsttab)
+ %layoutfirsttab=$new(tqlayout,%firsttab)
%labelbt=$new(label,%firsttab)
%labelbt->$settext(Botton Tab)
%labeltt=$new(label,%firsttab)
@@ -106,10 +106,10 @@
# Now we'll give a tqlayout to all items.
# This also allows to use privateimpl without making buttons global variables
- %tqlayoutfirsttab->$addwidget(%labelbt,0,0)
- %tqlayoutfirsttab->$addwidget(%labeltt,0,1)
- %tqlayoutfirsttab->$addwidget(%buttontb,1,0)
- %tqlayoutfirsttab->$addwidget(%buttontt,1,1)
+ %layoutfirsttab->$addwidget(%labelbt,0,0)
+ %layoutfirsttab->$addwidget(%labeltt,0,1)
+ %layoutfirsttab->$addwidget(%buttontb,1,0)
+ %layoutfirsttab->$addwidget(%buttontt,1,1)
# Add the page to the main tab.
%Tabwidget->$addTab(%firsttab,Top&Button,33)
@@ -125,15 +125,15 @@
}
# We do the same work with the second tab's page.
- %tqlayoutsecondtab=$new(tqlayout,%secondtab)
+ %layoutsecondtab=$new(tqlayout,%secondtab)
%labelwp=$new(label,%secondtab)
%labelwp->$settext("Enjoy the new Class provided by")
- %tqlayoutsecondtab->$addwidget(%labelwp,0,0)
+ %layoutsecondtab->$addwidget(%labelwp,0,0)
%labelwp->$settqalignment("Center")
%labelgen=$new(label,%secondtab)
%labelgen->$settext(Grifisx \& Noldor)
%labelgen->$settqalignment("Center")
- %tqlayoutsecondtab->$addwidget(%labelgen,1,0)
+ %layoutsecondtab->$addwidget(%labelgen,1,0)
%Tabwidget->$addTab(%secondtab,&About,50)
# Let's show our example.
@@ -182,7 +182,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_tabwidget)
bool KviKvsObject_tabwidget::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQTabWidget(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQTabWidget(parentScriptWidget(), name())), true);
connect(widget(),TQT_SIGNAL(currentChanged(int)),this,TQT_SLOT(slotcurrentChanged(int)));
return true;
}
diff --git a/src/modules/objects/class_tbrowser.cpp b/src/modules/objects/class_tbrowser.cpp
index 872a9c8..7f4de6c 100644
--- a/src/modules/objects/class_tbrowser.cpp
+++ b/src/modules/objects/class_tbrowser.cpp
@@ -82,7 +82,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_textbrowser)
bool KviKvsObject_textbrowser::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- TQTextBrowser * tb = new TQTextBrowser(tqparentScriptWidget(), name());
+ TQTextBrowser * tb = new TQTextBrowser(parentScriptWidget(), name());
setObject(TQT_TQOBJECT(tb), true);
connect(tb,TQT_SIGNAL(anchorClicked(const TQString &,const TQString &)),this,TQT_SLOT(anchorClicked(const TQString &,const TQString &)));
return true;
diff --git a/src/modules/objects/class_toolbar.cpp b/src/modules/objects/class_toolbar.cpp
index 036c31e..637feff 100644
--- a/src/modules/objects/class_toolbar.cpp
+++ b/src/modules/objects/class_toolbar.cpp
@@ -79,14 +79,14 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_toolbar)
bool KviKvsObject_toolbar::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- if (!tqparentObject())
+ if (!parentObject())
{
pContext->warning(__tr2qs("the toolbar cannot be a tqparent-widget!"));
return true;
}
- if(tqparentObject()->inherits("KviKvsObject_mainwindow"))
+ if(parentObject()->inherits("KviKvsObject_mainwindow"))
{
- setObject(TQT_TQOBJECT(new KviTalToolBar(name(), ((KviTalMainWindow *)tqparentScriptWidget()))), true);
+ setObject(TQT_TQOBJECT(new KviTalToolBar(name(), ((KviTalMainWindow *)parentScriptWidget()))), true);
}
else
{
diff --git a/src/modules/objects/class_toolbutton.cpp b/src/modules/objects/class_toolbutton.cpp
index c8efb26..5710706 100644
--- a/src/modules/objects/class_toolbutton.cpp
+++ b/src/modules/objects/class_toolbutton.cpp
@@ -129,7 +129,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_toolbutton)
bool KviKvsObject_toolbutton::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQToolButton(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQToolButton(parentScriptWidget(), name())), true);
connect(widget(),TQT_SIGNAL(clicked()),this,TQT_SLOT(slotClicked()));
return true;
}
diff --git a/src/modules/objects/class_vbox.cpp b/src/modules/objects/class_vbox.cpp
index edec898..d068156 100644
--- a/src/modules/objects/class_vbox.cpp
+++ b/src/modules/objects/class_vbox.cpp
@@ -67,7 +67,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_vbox)
bool KviKvsObject_vbox::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new KviTalVBox(tqparentScriptWidget())), true);
+ setObject(TQT_TQOBJECT(new KviTalVBox(parentScriptWidget())), true);
return true;
}
@@ -118,7 +118,7 @@ bool KviKvsObject_vbox::functionsetStretchFactor(KviKvsObjectFunctionCall *c)
return true;
}
- if(((KviKvsObject_widget *)pObject)->widget()->tqparentWidget() != widget())
+ if(((KviKvsObject_widget *)pObject)->widget()->parentWidget() != widget())
{
c->warning(__tr2qs("The widget must be a child of this vbox"));
return true;
diff --git a/src/modules/objects/class_widget.cpp b/src/modules/objects/class_widget.cpp
index 6790bbf..3e6b4b6 100644
--- a/src/modules/objects/class_widget.cpp
+++ b/src/modules/objects/class_widget.cpp
@@ -202,7 +202,7 @@ const int widgettypes_cod[] = {
!fn: $window.caption()
Returns the caption text of this widget.
!fn: $isTopLevel()
- Returns '1' if this widget is a toplevel (tqparentless) one,
+ Returns '1' if this widget is a toplevel (parentless) one,
'0' otherwise.
!fn: $isVisible()
Returns '1' if this widget is currently visible (read: is managed
@@ -222,7 +222,7 @@ const int widgettypes_cod[] = {
!fn: $setFocus()
Sets this widget to be the one that receives keyboard events.
See also [classfnc]$hasFocus[/classfnc]
- !fn: $tqparentWidget()
+ !fn: $parentWidget()
Returns the object id of the tqparent widget, or '0' if this
widget is a toplevel one.
!fn: $backgroundColor()
@@ -639,7 +639,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_widget)
bool KviKvsObject_widget::init(KviKvsRunTimeContext * pContext,KviKvsVariantList * pParams)
{
- setObject(TQT_TQOBJECT(new TQWidget(tqparentScriptWidget(),getName())),true);
+ setObject(TQT_TQOBJECT(new TQWidget(parentScriptWidget(),getName())),true);
return true;
}
@@ -1256,7 +1256,7 @@ bool KviKvsObject_widget::function_foregroundColor(KviKvsObjectFunctionCall *c)
bool KviKvsObject_widget::function_parentWidget(KviKvsObjectFunctionCall *c)
{
if(!widget())return true;
- if(tqparentScriptWidget()) c->returnValue()->setHObject(tqparentObject()->handle());
+ if(parentScriptWidget()) c->returnValue()->setHObject(parentObject()->handle());
else
c->returnValue()->setHObject((kvs_hobject_t)0);
return true;
@@ -1564,7 +1564,7 @@ bool KviKvsObject_widget::function_setWFlags(KviKvsObjectFunctionCall *c)
#ifdef COMPILE_USE_QT4
widget()->setWindowFlags(sum);
#else
- widget()->reparent(widget()->tqparentWidget(),sum,TQPoint(widget()->x(),widget()->y()));
+ widget()->reparent(widget()->parentWidget(),sum,TQPoint(widget()->x(),widget()->y()));
#endif
return true;
}
diff --git a/src/modules/objects/class_wizard.cpp b/src/modules/objects/class_wizard.cpp
index 6722650..3ea0c13 100644
--- a/src/modules/objects/class_wizard.cpp
+++ b/src/modules/objects/class_wizard.cpp
@@ -124,7 +124,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_wizard)
bool KviKvsObject_wizard::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new KviKvsMdmWizard(tqparentScriptWidget(), name(),this)), true);
+ setObject(TQT_TQOBJECT(new KviKvsMdmWizard(parentScriptWidget(), name(),this)), true);
return true;
}
diff --git a/src/modules/objects/class_workspace.cpp b/src/modules/objects/class_workspace.cpp
index 90e3687..4809277 100644
--- a/src/modules/objects/class_workspace.cpp
+++ b/src/modules/objects/class_workspace.cpp
@@ -184,7 +184,7 @@ KVSO_END_CONSTRUCTOR(KviKvsObject_workspace)
bool KviKvsObject_workspace::init(KviKvsRunTimeContext * pContext,KviKvsVariantList *pParams)
{
- setObject(TQT_TQOBJECT(new TQWorkspace(tqparentScriptWidget(), name())), true);
+ setObject(TQT_TQOBJECT(new TQWorkspace(parentScriptWidget(), name())), true);
return true;
}
diff --git a/src/modules/options/dialog.cpp b/src/modules/options/dialog.cpp
index 6b5f6e8..10117d2 100644
--- a/src/modules/options/dialog.cpp
+++ b/src/modules/options/dialog.cpp
@@ -655,7 +655,7 @@ void KviOptionsDialog::recursiveCommit(KviOptionsListViewItem *it)
recursiveCommit(it2);
it2 = (KviOptionsListViewItem *)it2->nextSibling();
}
- // then the tqparents
+ // then the parents
if(it->m_pOptionsWidget)
{
it->m_pOptionsWidget->commit();
diff --git a/src/modules/popupeditor/popupeditor.cpp b/src/modules/popupeditor/popupeditor.cpp
index 99beab9..38c5bd5 100644
--- a/src/modules/popupeditor/popupeditor.cpp
+++ b/src/modules/popupeditor/popupeditor.cpp
@@ -374,12 +374,12 @@ void KviSinglePopupEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt
{
m_pContextPopup->clear();
- KviPopupListViewItem * tqparentMenu = 0;
+ KviPopupListViewItem * parentMenu = 0;
bool bIsMenu = false;
if(it)
{
- tqparentMenu = (KviPopupListViewItem *) (((KviPopupListViewItem *)it)->tqparent());
+ parentMenu = (KviPopupListViewItem *) (((KviPopupListViewItem *)it)->tqparent());
bIsMenu = ((KviPopupListViewItem *)it)->m_type == KviPopupListViewItem::Menu;
}
@@ -464,7 +464,7 @@ void KviSinglePopupEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt
bool bSeparatorInserted = false;
-// if(!findPrologue(tqparentMenu))
+// if(!findPrologue(parentMenu))
// {
m_pContextPopup->insertSeparator();
bSeparatorInserted = true;
@@ -473,7 +473,7 @@ void KviSinglePopupEditor::itemPressed(KviTalListViewItem *it,const TQPoint &pnt
__tr2qs("New Menu Prologue"),this,TQT_SLOT(contextNewPrologue()));
// }
-// if(!findEpilogue(tqparentMenu))
+// if(!findEpilogue(parentMenu))
// {
if(!bSeparatorInserted)m_pContextPopup->insertSeparator();
m_pContextPopup->insertItem(
diff --git a/src/modules/regchan/libkviregchan.cpp b/src/modules/regchan/libkviregchan.cpp
index 4af1512..51fb91d 100644
--- a/src/modules/regchan/libkviregchan.cpp
+++ b/src/modules/regchan/libkviregchan.cpp
@@ -95,7 +95,7 @@ static bool regchan_kvs_cmd_add(KviKvsModuleCommandCall * c)
If no match for <channel>/<network> is found in the database then
a warning is printed unless -q is used.[br]
If -e is specified then <network> is not matched against the
- nettqmasks in the database but is compared directly. This means
+ netmasks in the database but is compared directly. This means
that <network> must be exactly the nettqmask used to register a channel.
@examples:
[example]
@@ -144,7 +144,7 @@ static bool regchan_kvs_cmd_remove(KviKvsModuleCommandCall * c)
No warning on screen.
!fn: -e|--exactly
If -e is specified then <network> is not matched against the
- nettqmasks in the database but is compared directly. This means
+ netmasks in the database but is compared directly. This means
that <network> must be exactly the nettqmask used to register a channel.
@examples:
[example]
diff --git a/src/modules/reguser/dialog.cpp b/src/modules/reguser/dialog.cpp
index 59c272d..1f816ed 100644
--- a/src/modules/reguser/dialog.cpp
+++ b/src/modules/reguser/dialog.cpp
@@ -344,7 +344,7 @@ void KviRegisteredUsersDialog::itemPressed(KviTalListViewItem *it,const TQPoint
// try to find the nicknames to be notified
TQString szMask;
- for(KviIrcMask * m = i->user()->tqmaskList()->first();m;m = i->user()->tqmaskList()->next())
+ for(KviIrcMask * m = i->user()->maskList()->first();m;m = i->user()->maskList()->next())
{
TQString tmp = m->nick();
if((tmp.tqfind('*') == -1) && (tmp.tqfind('?') == -1) && (!tmp.isEmpty()))
@@ -717,7 +717,7 @@ void KviRegisteredUsersDialog::exportClicked()
if(!f.save(0))goto write_error;
}
- KviPointerList<KviIrcMask> * ml = u->tqmaskList();
+ KviPointerList<KviIrcMask> * ml = u->maskList();
if(ml)
{
if(!f.save(ml->count()))goto write_error;
diff --git a/src/modules/reguser/edituser.cpp b/src/modules/reguser/edituser.cpp
index 6fd82ca..9701915 100644
--- a/src/modules/reguser/edituser.cpp
+++ b/src/modules/reguser/edituser.cpp
@@ -208,7 +208,7 @@ void KviReguserPropertiesDialog::delClicked()
KviReguserMaskDialog::KviReguserMaskDialog(TQWidget * p,KviIrcMask * m)
-: TQDialog(p,"reguser_tqmask_editor",true)
+: TQDialog(p,"reguser_mask_editor",true)
{
m_pMask = m;
@@ -356,7 +356,7 @@ KviRegisteredUserEntryDialog::KviRegisteredUserEntryDialog(TQWidget *p,KviRegist
g->addMultiCellWidget(l,3,3,0,1);
m_pMaskListBox = new KviTalListBox(p1);
- connect(m_pMaskListBox,TQT_SIGNAL(currentChanged(KviTalListBoxItem *)),this,TQT_SLOT(tqmaskCurrentChanged(KviTalListBoxItem *)));
+ connect(m_pMaskListBox,TQT_SIGNAL(currentChanged(KviTalListBoxItem *)),this,TQT_SLOT(maskCurrentChanged(KviTalListBoxItem *)));
m_pMaskListBox->setMinimumSize(300,200);
g->addMultiCellWidget(m_pMaskListBox,4,4,0,1);
@@ -494,7 +494,7 @@ KviRegisteredUserEntryDialog::KviRegisteredUserEntryDialog(TQWidget *p,KviRegist
{
m_pNameEdit->setText(r->name());
m_pCommentEdit->setText(r->getProperty("comment"));
- for(KviIrcMask * m = r->tqmaskList()->first();m;m = r->tqmaskList()->next())
+ for(KviIrcMask * m = r->maskList()->first();m;m = r->maskList()->next())
{
TQString mk = m->nick();
mk += TQChar('!');
@@ -555,7 +555,7 @@ KviRegisteredUserEntryDialog::~KviRegisteredUserEntryDialog()
delete m_pCustomColor;
}
-void KviRegisteredUserEntryDialog::tqmaskCurrentChanged(KviTalListBoxItem *it)
+void KviRegisteredUserEntryDialog::maskCurrentChanged(KviTalListBoxItem *it)
{
m_pDelMaskButton->setEnabled(it);
m_pEditMaskButton->setEnabled(it);
diff --git a/src/modules/reguser/edituser.h b/src/modules/reguser/edituser.h
index 0318dbd..cba94c5 100644
--- a/src/modules/reguser/edituser.h
+++ b/src/modules/reguser/edituser.h
@@ -147,7 +147,7 @@ protected slots:
void delMaskClicked();
void editMaskClicked();
void editAllPropertiesClicked();
- void tqmaskCurrentChanged(KviTalListBoxItem *it);
+ void maskCurrentChanged(KviTalListBoxItem *it);
};
diff --git a/src/modules/reguser/wizard.cpp b/src/modules/reguser/wizard.cpp
index 8d61617..75693b3 100644
--- a/src/modules/reguser/wizard.cpp
+++ b/src/modules/reguser/wizard.cpp
@@ -109,7 +109,7 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
m_pPage2Layout->setMargin( 8 );
m_pLabel2 = new TQLabel( m_pPage2);
- m_pLabel2->setText(__tr2qs("<p>A registered user is identified by one or more <b>IRC tqmasks</b>.<br>A tqmask must be in the following form:<br><b>nickname!username@hostname</b><br>and can contain wildcard characters '*' and '?'. Be careful in choosing the tqmasks, as they are the only way to verify the identity of a registered user.<br><br>You can enter at most two tqmasks here, if you wish to add more tqmasks, use the \"<b>Edit</b>\" button in the Registered Users dialog. You must enter at least one tqmask.</p>"));
+ m_pLabel2->setText(__tr2qs("<p>A registered user is identified by one or more <b>IRC masks</b>.<br>A tqmask must be in the following form:<br><b>nickname!username@hostname</b><br>and can contain wildcard characters '*' and '?'. Be careful in choosing the masks, as they are the only way to verify the identity of a registered user.<br><br>You can enter at most two masks here, if you wish to add more masks, use the \"<b>Edit</b>\" button in the Registered Users dialog. You must enter at least one tqmask.</p>"));
m_pPage2Layout->addMultiCellWidget(m_pLabel2,0,0,0,4);
@@ -117,23 +117,23 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
//tqmask.tqmask(szMask,11);
- //KviIrcMask tqmasktempl(szMask.ptr());
+ //KviIrcMask masktempl(szMask.ptr());
m_pNicknameEdit1 = new TQLineEdit(m_pPage2);
m_pNicknameEdit1->tqsetAlignment(TQt::AlignRight);
if(tqmask.nick() != "*")m_pNicknameEdit1->setText(tqmask.nick());
- connect(m_pNicknameEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(tqmaskChanged(const TQString &)));
+ connect(m_pNicknameEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(maskChanged(const TQString &)));
m_pPage2Layout->addWidget( m_pNicknameEdit1, 1, 0 );
m_pUsernameEdit1 = new TQLineEdit(m_pPage2);
m_pUsernameEdit1->tqsetAlignment(TQt::AlignHCenter);
if(tqmask.hasUser())m_pUsernameEdit1->setText(tqmask.user());
- connect(m_pUsernameEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(tqmaskChanged(const TQString &)));
+ connect(m_pUsernameEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(maskChanged(const TQString &)));
m_pPage2Layout->addWidget(m_pUsernameEdit1,1,2);
m_pHostEdit1 = new TQLineEdit(m_pPage2);
if(tqmask.hasHost())m_pHostEdit1->setText(tqmask.host());
- connect(m_pHostEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(tqmaskChanged(const TQString &)));
+ connect(m_pHostEdit1,TQT_SIGNAL(textChanged(const TQString &)),this,TQT_SLOT(maskChanged(const TQString &)));
m_pPage2Layout->addWidget(m_pHostEdit1,1,4);
m_pNicknameEdit2 = new TQLineEdit(m_pPage2);
@@ -255,7 +255,7 @@ KviRegistrationWizard::KviRegistrationWizard(const char * startMask,KviRegistere
setFinishEnabled(m_pPage5,true);
TQString dummy;
- tqmaskChanged(dummy);
+ maskChanged(dummy);
realNameChanged(dummy);
notifyCheckToggled(false);
@@ -391,7 +391,7 @@ void KviRegistrationWizard::showEvent(TQShowEvent *e)
KviTalWizard::showEvent(e);
}
-void KviRegistrationWizard::tqmaskChanged(const TQString &)
+void KviRegistrationWizard::maskChanged(const TQString &)
{
KviStr tmp1 = m_pNicknameEdit1->text();
KviStr tmp2 = m_pUsernameEdit1->text();
diff --git a/src/modules/reguser/wizard.h b/src/modules/reguser/wizard.h
index 23cb457..209eaab 100644
--- a/src/modules/reguser/wizard.h
+++ b/src/modules/reguser/wizard.h
@@ -82,7 +82,7 @@ protected:
virtual void reject();
protected slots:
void realNameChanged(const TQString &str);
- void tqmaskChanged(const TQString &str);
+ void maskChanged(const TQString &str);
void notifyNickChanged(const TQString &);
void notifyCheckToggled(bool);
};
diff --git a/src/modules/system/libkvisystem.cpp b/src/modules/system/libkvisystem.cpp
index d81524a..df68402 100644
--- a/src/modules/system/libkvisystem.cpp
+++ b/src/modules/system/libkvisystem.cpp
@@ -420,7 +420,7 @@ static bool system_kvs_fnc_hostname(KviKvsModuleFunctionCall *c)
identifier of the object called, <function> is the function to be executed
on the remote object and <parameter1>,<parameter2>,... is the list of
parameters to be passed. The <function> name must contain the
- trailing tqparenthesis and parameter specification (see examples).
+ trailing parenthesis and parameter specification (see examples).
The parameters MUST be in the form "type=value"
where "type" is the C++ type of the parameter and value
is the string rappresentation of the parameter data. Currently
diff --git a/src/modules/tip/libkvitip_it.kvc b/src/modules/tip/libkvitip_it.kvc
index 481e7e3..edabad6 100644
--- a/src/modules/tip/libkvitip_it.kvc
+++ b/src/modules/tip/libkvitip_it.kvc
@@ -6,7 +6,7 @@ TranslatorHint=This-file-MUST-be-encoded-in-UTF8
1=IPv6 ora è supportato completamente, anche per le connessioni DCC.<br>Il comando è <b>/server -i &lt;nomeserver&gt;</b> :)
2=KVIrc supporta crittazione SSL.<br>Le connessioni IRC crittate con SSL possono essere stabilite usando <b>/server -s</b>, e connessioni DCC usando <b>/dcc.chat -s</b><br>Funziona anche usando IPv6.
3=Un <b>contesto IRC</b> è un set di risorse che dialogano con una singola connessione server. Ha associato una finestra <b>Console</b> che mostra i messaggi di sistema e del server.
-4=KVIrc è un'applicazione altamente modulare. I moduli sono caricati e scaricati trastqparentemente all'utente (ed anche allo scripter!). Puoi anche scrivere i tuoi moduli personali che estendono il linguaggio di scripting o aggiungono altre funzionalità.
+4=KVIrc è un'applicazione altamente modulare. I moduli sono caricati e scaricati trasparentemente all'utente (ed anche allo scripter!). Puoi anche scrivere i tuoi moduli personali che estendono il linguaggio di scripting o aggiungono altre funzionalità.
5=Il modulo <b>gnutella</b> è stato rimosso dai sorgenti di KVIrc ed è ora distribuito in un pacchetto separato.
6=KVIrc supporta diversi gestori per lo stesso evento. Questo permette di avere diversi script installati allo stesso momento, evitare collisioni tra gestori ed aiutare ad aggiungere/rimuovere e attivare/disattivare gli script.
7=KVIrc supporta gli URL (Uniform Resource Locator) <b>irc://</b>. Lancia il comando:<br><b>kvirc irc://irc.tuoserver.org:6667/canale</b><br> per connettere a quel server.<br>La sintassi generale è:<br><b>irc[6]://&lt;nome-server&gt;[:&lt;porta&gt;][/[&lt;canale&gt;[?&lt;password&gt;]]]</b>
diff --git a/src/modules/toolbareditor/toolbareditor.cpp b/src/modules/toolbareditor/toolbareditor.cpp
index 3f3d9d1..c392a7f 100644
--- a/src/modules/toolbareditor/toolbareditor.cpp
+++ b/src/modules/toolbareditor/toolbareditor.cpp
@@ -358,7 +358,7 @@ void KviCustomizeToolBarsDialog::currentToolBarChanged()
void KviCustomizeToolBarsDialog::showEvent(TQShowEvent * e)
{
// repaintContents();
-// TQRect r = tqparentWidget() ? tqparentWidget()->rect() : TQApplication::desktop()->rect();
+// TQRect r = parentWidget() ? parentWidget()->rect() : TQApplication::desktop()->rect();
// int x = (r.width() - width()) / 2;
// int y = (r.height() - height()) / 2;
// move(x,y);
diff --git a/src/modules/reguser/libkvireguser.cpp b/src/modules/reguser/libkvireguser.cpp
index b836317..86bac9f 100644
--- a/src/modules/reguser/libkvireguser.cpp
+++ b/src/modules/reguser/libkvireguser.cpp
@@ -73,11 +73,11 @@ KviRegisteredUsersDialog * g_pRegisteredUsersDialog = 0;
[fnc]$reguser.list[/fnc]: lists the entries[br]
[cmd]reguser.setproperty[/cmd]: sets a property associated to an entry[br]
[cmd]reguser.edit[/cmd]: shows an editor for an user entry
- [fnc]$reguser.match[/fnc](): finds an entry by matching tqmasks[br]
- [fnc]$reguser.exactMatch[/fnc](): finds an entry by comparing tqmasks[br]
+ [fnc]$reguser.match[/fnc](): finds an entry by matching masks[br]
+ [fnc]$reguser.exactMatch[/fnc](): finds an entry by comparing masks[br]
[fnc]$reguser.property[/fnc](): finds a property associated to an entry[br]
[fnc]$reguser.matchProperty[/fnc](): shortcut for [fnc]$reguser.property[/fnc]([fnc]$reguser.match[/fnc]())[br]
- [fnc]$reguser.tqmask[/fnc](): returns the registration tqmasks for an entry
+ [fnc]$reguser.tqmask[/fnc](): returns the registration masks for an entry
*/
/*
@@ -155,7 +155,7 @@ static bool reguser_kvs_cmd_edit(KviKvsModuleCommandCall * c)
Adds a new entry with the specified <name> to the database.[br]
If the database contains an entry with the same <name>, this command just prints
a warning and returns.[br]
- If no [tqmask] is given the new entry has no registration tqmasks: so it can't be "matched" yet. You have to add
+ If no [tqmask] is given the new entry has no registration masks: so it can't be "matched" yet. You have to add
at least one tqmask with [cmd]reguser.addtqmask[/cmd].
If [tqmask] is given, then it is added to the entry tqmask list.[br]
The <name> parameter may contain any character: even spaces are allowed (obviously you have to
@@ -293,7 +293,7 @@ static bool reguser_kvs_cmd_remove(KviKvsModuleCommandCall * c)
reguser.addtqmask [-f] <name> <tqmask>
@description:
Adds a registration tqmask to the database entry with name <name>.[br]
- The <tqmask> has the common [doc:irc_tqmasks]irc tqmask[/doc] format.[br]
+ The <tqmask> has the common [doc:irc_masks]irc tqmask[/doc] format.[br]
The only restriction on the <tqmask> is that it must be unique inside the
regusers database: you can't match two users with the same tqmask (it would
have rather undefined results).[br]
@@ -301,7 +301,7 @@ static bool reguser_kvs_cmd_remove(KviKvsModuleCommandCall * c)
and associates is to THIS registered user (breaking the previous associations).<br>
Once at least one tqmask has been added, the user can be "matched"
by using the [fnc]$reguser.match[/fnc]() function.[br]
- Each database entry can have an unlimited number of tqmasks.[br]
+ Each database entry can have an unlimited number of masks.[br]
@examples:
[example]
[cmd]reguser.add[/cmd] "Szymon Stefanek"
@@ -370,7 +370,7 @@ static bool reguser_kvs_cmd_addtqmask(KviKvsModuleCommandCall * c)
reguser.deltqmask <tqmask>
@description:
Removes a tqmask from the regusers database.[br]
- Since tqmasks are unique in the database , you don't need to pass
+ Since masks are unique in the database , you don't need to pass
an <user> parameter: if an <user> entry has the <tqmask>, removing that <tqmask>
will surely remove it from that <user> entry. (contorsions ?)[br]
@examples:
@@ -720,13 +720,13 @@ static bool reguser_kvs_cmd_setproperty(KviKvsModuleCommandCall * c)
@title:
$reguser.list
@short:
- Get a list of registered user tqmasks
+ Get a list of registered user masks
@syntax:
$reguser.list([tqmask])
@description:
Returns an array of the entries in the registered users database.[br]
If <tqmask> is specified, only entries matching the <tqmask>
- and the entries with no registration tqmasks are listed.[br]
+ and the entries with no registration masks are listed.[br]
Please note that <tqmask> is a wildcard string that will match
wildcard strings... don't get messed with that :D[br]
@seealso:
@@ -758,7 +758,7 @@ static bool reguser_kvs_fnc_list(KviKvsModuleFunctionCall * c)
while(KviRegisteredUser * u = it.current())
{
- KviPointerList<KviIrcMask> * ml = u->tqmaskList();
+ KviPointerList<KviIrcMask> * ml = u->maskList();
if(u->matches(tqmask) || (ml->count() == 0))
{
pArray->set(aid,new KviKvsVariant(u->name()));
@@ -785,7 +785,7 @@ static bool reguser_kvs_fnc_list(KviKvsModuleFunctionCall * c)
@description:
Lists the entries in the registered users database.[br]
If <tqmask> is specified, only entries matching the <tqmask>
- and the entries with no registration tqmasks are listed.[br]
+ and the entries with no registration masks are listed.[br]
Please note that <tqmask> is a wildcard string that will match
wildcard strings... don't get messed with that :D[br]
@seealso:
@@ -813,14 +813,14 @@ static bool reguser_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
KviPointerHashTableIterator<TQString,KviRegisteredUser> it(*d);
while(KviRegisteredUser * u = it.current())
{
- KviPointerList<KviIrcMask> * ml = u->tqmaskList();
+ KviPointerList<KviIrcMask> * ml = u->maskList();
if(u->matches(tqmask) || (ml->count() == 0))
{
c->window()->output(KVI_OUT_SYSTEMMESSAGE,__tr2qs(" User: %c%Q"),KVI_TEXT_BOLD,&(u->name()));
if(ml->count() == 0)
{
- c->window()->output(KVI_OUT_SYSTEMWARNING,__tr2qs(" Warning: this user has no registration tqmasks"));
+ c->window()->output(KVI_OUT_SYSTEMWARNING,__tr2qs(" Warning: this user has no registration masks"));
} else {
for(KviIrcMask * m = ml->first();m;m = ml->next())
{
@@ -862,7 +862,7 @@ static bool reguser_kvs_cmd_showlist(KviKvsModuleCommandCall * c)
$reguser.match(<user_tqmask>)
@description:
Returns the name of the first entry matching <user_tqmask> in the registered user database.[br]
- The <user_tqmask> has the common [doc:irc_tqmasks]irc tqmask[/doc] format but can't contain wildcards.[br]
+ The <user_tqmask> has the common [doc:irc_masks]irc tqmask[/doc] format but can't contain wildcards.[br]
@seealso:
[module:reguser]Registered users database interface[/module],
[doc:registered_users]Registered users database[/doc],
@@ -899,7 +899,7 @@ static bool reguser_kvs_fnc_match(KviKvsModuleFunctionCall * c)
$reguser.exactMatch(<user_tqmask>)
@description:
Returns the name of the registered user database entry that has <user_tqmask> in its registration tqmask list.[br]
- The <user_tqmask> has the common [doc:irc_tqmasks]wild irc tqmask[/doc] format and can contain wildcards.[br]
+ The <user_tqmask> has the common [doc:irc_masks]wild irc tqmask[/doc] format and can contain wildcards.[br]
@seealso:
[module:reguser]Registered users database interface[/module],
[doc:registered_users]Registered users database[/doc],
@@ -934,7 +934,7 @@ static bool reguser_kvs_fnc_exactMatch(KviKvsModuleFunctionCall * c)
// @syntax:
// $reguser.matches(<user_tqmask>)
// @description:
// Returns a comma separated list of registered user tqmasks that match <user_tqmask>.[br]
// User tqmask must be in the format <nick>!<user>@<host> , where <user> and
// <host> may contain '*' wildcards.[br]
// If no registered tqmask matches the <user_tqmask> an empty string is returned.[br]
@@ -983,14 +983,14 @@ static bool reguser_kvs_fnc_exactMatch(KviKvsModuleFunctionCall * c)
@title:
$reguser.tqmask
@short:
- Returns the registration tqmasks for a db entry
+ Returns the registration masks for a db entry
@syntax:
$reguser.tqmask(<name>[,<N>])
@description:
Returns the <N>th registration tqmask for the registered user database record identified
- by <name>. If <N> is not given , returns an array of registration tqmasks for that entry.[br]
+ by <name>. If <N> is not given , returns an array of registration masks for that entry.[br]
If <name> does not identify a valid entry an empty string is returned;
- if <N> is out of range (or there are no tqmasks at all) , an empty string is returned.[br]
+ if <N> is out of range (or there are no masks at all) , an empty string is returned.[br]
<N> is a ZERO BASED index.[br]
@examples:
[example]
@@ -1027,11 +1027,11 @@ static bool reguser_kvs_fnc_tqmask(KviKvsModuleFunctionCall * c)
KviStr n = szName;
if(n.hasData() && n.isUnsignedNum())
{
- KviIrcMask * m = u->tqmaskList()->at(n.toInt());
+ KviIrcMask * m = u->maskList()->at(n.toInt());
if(m) c->returnValue()->setString(m->nick()+"!"+m->user()+"@"+m->host());
} else {
int id=0;
- for(KviIrcMask * m = u->tqmaskList()->first();m;m = u->tqmaskList()->next())
+ for(KviIrcMask * m = u->maskList()->first();m;m = u->maskList()->next())
{
pArray->set(aid,new KviKvsVariant(TQString(m->nick()+"!"+m->user()+"@"+m->host())));
aid++;
@@ -934,7 +934,7 @@ static bool reguser_kvs_fnc_exactMatch(KviKvsModuleFunctionCall * c)
// $reguser.matches(<user_tqmask>)
// @description:
-// Returns a comma separated list of registered user tqmasks that match <user_tqmask>.[br]
+// Returns a comma separated list of registered user masks that match <user_tqmask>.[br]
// User tqmask must be in the format <nick>!<user>@<host> , where <user> and
// <host> may contain '*' wildcards.[br]